@@ -24,13 +24,13 @@ struct find_instances
 : descender_preferred_order< find_instances< Spec >, Spec >
 {
 
-    typedef Spec                                                          spec;              ///< Specifications.
-    STEME_TYPEDEF_SEQAN_TYPES( spec )
+    STEME_TYPEDEF_SEQAN_TYPES( Spec )
     typedef find_instances< Spec >                                        this_t;            ///< This type.
     typedef boost::shared_ptr< this_t >                                   ptr;               ///< Pointer.
     typedef tree_descender< this_t, Spec >                                base_t;            ///< Base type.
-    typedef std::vector< w_mer_evaluation >                               instances_vec;     ///< Vector of instances.
-    typedef boost::shared_ptr< instances_vec >                            instances_vec_ptr; ///< Pointer to instances.
+    typedef w_mer_evaluation< Spec >                                      eval_t;            ///< Evaluation type.
+    typedef typename eval_t::vec                                         instances_vec;     ///< Vector of instances.
+    typedef typename eval_t::vec_ptr                                     instances_vec_ptr; ///< Pointer to instances.
 
     double                              Z_threshold;      ///< Z threshold at which to ignore instances.
     instances_vec_ptr                    instances;        ///< Instances.
@@ -39,8 +39,8 @@ struct find_instances
 
     /** Constructor. */
     find_instances(
-        data< spec > &         _data,
-        model< spec > &        _model,
+        data< Spec > &         _data,
+        model< Spec > &        _model,
         double                 Z_threshold
     )
     : descender_preferred_order< this_t, Spec >( _data, _model )
@@ -80,7 +80,7 @@ struct find_instances
     inline
     void
     handle_W_mer_occurrence_one_strand(
-        int global_pos,
+        global_pos_t global_pos,
         double Z_strand,
         double g_n,
         double lambda,
@@ -89,7 +89,7 @@ struct find_instances
         double log_p_background
     ) {
         if( Z_strand >= Z_threshold ) {
-            instances->push_back( w_mer_evaluation( Z_strand, global_pos, RevComp ) );
+            instances->push_back( w_mer_evaluation< Spec >( Z_strand, global_pos, RevComp ) );
         }
     }
 
