@@ -553,6 +553,10 @@ def occurrences_from_index(index):
         i = Iterator(index)
         return i.goDownBase(base) and i.num_occurrences or 0
     freqs = N.array(map(get_base_occurrences, 'ACGTN'), dtype=float)
+    unknown_warning_threshold = .9
+    unknown_freq = freqs[4] / freqs.sum()
+    if unknown_freq > unknown_warning_threshold:
+        logger.warning('%.1f%% of the bases in the sequences are unknown', 100. * unknown_freq)
     return freqs
 
 
@@ -2035,7 +2039,8 @@ class Algorithm(object):
                 logger.warning('Hit cap of %d on maximum # sites, user can over-ride this with the --max-sites option. High values will slow STEME down.' % hard_limit)
             logger.info('Set maximum number of sites to %d', self.options.max_num_sites)
         if not self.options.min_num_sites:
-            self.options.min_num_sites = max(len(self.input_sequences.seqs) / 10, 2) # always look for at least 2 sites
+            # always look for at least 2 sites unless max_num_sites is small
+            self.options.min_num_sites = max(len(self.input_sequences.seqs) / 10, min(2, self.options.max_num_sites))
             logger.info('Set minimum number of sites to %d', self.options.min_num_sites)
         
         
